(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, (global.AlpineMagicHelpers = global.AlpineMagicHelpers || {}, global.AlpineMagicHelpers.range = factory()));
}(this, (function () { 'use strict';

    var checkForAlpine = function checkForAlpine() {
      if (!window.Alpine) {
        throw new Error('[Magic Helpers] Alpine is required for the magic helpers to function correctly.');
      }

      if (!window.Alpine.version || !isValidVersion('2.5.0', window.Alpine.version)) {
        throw new Error('Invalid Alpine version. Please use Alpine version 2.5.0 or above');
      }
    };

    function isValidVersion(required, current) {
      var requiredArray = required.split('.');
      var currentArray = current.split('.');

      for (var i = 0; i < requiredArray.length; i++) {
        if (!currentArray[i] || parseInt(currentArray[i]) < parseInt(requiredArray[i])) {
          return false;
        }
      }

      return true;
    }

    var AlpineRangeMagicMethod = {
      start: function start() {
        checkForAlpine();
        Alpine.addMagicProperty('range', function () {
          return function (start, stop, step) {
            if (step === void 0) {
              step = 1;
            }

            // Accept $range(10) and expect 1...10
            if (typeof stop === 'undefined') {
              stop = start;
              start = start ? 1 : 0;
            } // Accept $range(20, 10) and expect 20...10


            var reverse = start > stop;

            if (reverse) {
              var _ref = [stop, start];
              start = _ref[0];
              stop = _ref[1];
            } // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/from#Sequence_generator_range


            var range = Array.from({
              length: (stop - start) / step + 1
            }, function (_, i) {
              return start + i * step;
            });
            return reverse ? range.reverse() : range;
          };
        });
      }
    };

    var alpine = window.deferLoadingAlpine || function (alpine) {
      return alpine();
    };

    window.deferLoadingAlpine = function (callback) {
      AlpineRangeMagicMethod.start();
      alpine(callback);
    };

    return AlpineRangeMagicMethod;

})));
